@@ -10,17 +10,21 @@ class DbSeeder():
     def __init__(self, crud_module) -> None:
         self.crud = crud_module
 
-    async def read_index(self, main_path="../seeds/", index_path="index.json"):
+    async def read_index(
+        self, 
+        main_path:str="../seeds/", 
+        index_path:str="index.json"
+    ) -> bool:
         index = open(path.join(main_path, index_path), "r")
         index_content = "".join(index.readlines())
         index.close()
         classes = loads(index_content)
         for cls in classes:
-            fil = open(path.join(main_path, cls['name'] + ".json"), "r")
+            fil = open(path.join(main_path, f"{cls['name']}.json"), "r")
             fil_content = "".join(fil.readlines())
             fil.close()
             objects = loads(fil_content)
-            crud_obj: BaseCrud = eval("self.crud." + cls['crud'])
+            crud_obj: BaseCrud = eval(f"self.crud.{cls['crud']}.crud")
             for obj in objects:
                 await crud_obj.create(obj)
         return True
